// This file was autogenerated. Do not edit it manually.
## Device List
### ophyd_devices 
| Device | Documentation | Module |
| :----- | :------------- | :------ |
| EpicsMotorEx | Extend EpicsMotor with extra configuration fields.<br>    motor_done_move<br>    motor_is_moving<br>     | [ophyd_devices.devices.epics_motor_ex](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/epics_motor_ex.py) |
| SLSDetector |  | [ophyd_devices.devices.sls_detector](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_detector.py) |
| SLSDetectorCam |  | [ophyd_devices.devices.sls_detector](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_detector.py) |
| SLSInfo |  | [ophyd_devices.devices.sls_devices](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_devices.py) |
| SLSOperatorMessages |  | [ophyd_devices.devices.sls_devices](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/sls_devices.py) |
| SpmBase | Python wrapper for the Staggered Blade Pair Monitors<br><br>    SPM's consist of a set of four horizontal tungsten blades and are<br>    used to monitor the beam height (only Y) for the bending magnet<br>    beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the users can<br>    change the beam position offset.<br>     | [ophyd_devices.devices.SpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/SpmBase.py) |
| SpmSim | Python wrapper for simulated Staggered Blade Pair Monitors<br><br>    SPM's consist of a set of four horizontal tungsten blades and are<br>    used to monitor the beam height (only Y) for the bending magnet<br>    beamlines of SLS.<br><br>    This simulation device extends the basic proxy with a script that<br>    fills signals with quasi-randomized values.<br>     | [ophyd_devices.devices.SpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/SpmBase.py) |
| XbpmBase | Python wrapper for X-ray Beam Position Monitors<br><br>    XBPM's consist of a metal-coated diamond window that ejects<br>    photoelectrons from the incoming X-ray beam. These electons<br>    are collected and their current is measured. Effectively<br>    they act as four quadrant photodiodes and are used as BPMs<br>    at the undulator beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the user can<br>    change the beam position offset.<br>     | [ophyd_devices.devices.XbpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/XbpmBase.py) |
| XbpmSim | Python wrapper for simulated X-ray Beam Position Monitors<br><br>    XBPM's consist of a metal-coated diamond window that ejects<br>    photoelectrons from the incoming X-ray beam. These electons<br>    are collected and their current is measured. Effectively<br>    they act as four quadrant photodiodes and are used as BPMs<br>    at the undulator beamlines of SLS.<br><br>    Note: EPICS provided signals are read only, but the user can<br>       change the beam position offset.<br><br>    This simulation device extends the basic proxy with a script that<br>    fills signals with quasi-randomized values.<br>     | [ophyd_devices.devices.XbpmBase](https://gitlab.psi.ch/bec/ophyd_devices/-/blob/main/ophyd_devices/devices/XbpmBase.py) |
